pub enum MemoryMapKind {
    MapFile(*const u8),
    MapVirtual,
}
Type of memory map

Variants

MapFile(*const u8)

Virtual memory map. Usually used to change the permissions of a given chunk of memory. Corresponds to VirtualAlloc on Windows.

MapVirtual

Virtual memory map. Usually used to change the permissions of a given chunk of memory, or for allocation. Corresponds to VirtualAlloc on Windows.