Struct mmap_fixed_fixed::MemoryMap
source · [−]pub struct MemoryMap { /* private fields */ }Expand description
A memory mapped file or chunk of memory. This is a very system-specific
interface to the OS’s memory mapping facilities (mmap on POSIX,
VirtualAlloc/CreateFileMapping on Windows). It makes no attempt at
abstracting platform differences, besides in error values returned. Consider
yourself warned.
The memory map is released (unmapped) when the destructor is run, so don’t let it leave scope by accident if you want it to stick around.
Implementations
sourceimpl MemoryMap
impl MemoryMap
sourcepub fn new(min_len: usize, options: &[MapOption]) -> Result<MemoryMap, MapError>
pub fn new(min_len: usize, options: &[MapOption]) -> Result<MemoryMap, MapError>
Create a new mapping with the given options, at least min_len bytes
long. min_len must be greater than zero; see the note on
ErrZeroLength.
sourcepub fn granularity() -> usize
pub fn granularity() -> usize
Granularity that the offset or address must be for MapOffset and
MapAddr respectively.